@@ -1,23 +1,25 @@
+use anyhow::Result;
 use chrono::prelude::*;
 use httpredis::{
-    errors::Error::{Timeout, Tls, IO},
     options,
     options::Redis,
+    rejections::{handle_rejection, RequestTimeout, ServiceUnavailable},
+};
+use std::{
+    net::{IpAddr, Ipv4Addr},
+    str::FromStr,
+    time::Duration,
 };
-use std::net::{IpAddr, Ipv4Addr};
-use std::str::FromStr;
-use std::time::Duration;
 use tokio::{
     io::{AsyncBufReadExt, AsyncWriteExt, BufStream},
     net::TcpStream,
     time::timeout,
 };
 use tokio_native_tls::{TlsConnector, TlsStream};
-use warp::http::StatusCode;
-use warp::Filter;
+use warp::{http::StatusCode, Filter};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
+async fn main() -> Result<()> {
     let redis: options::Redis = options::new()?;
 
     let port = redis.port;
@@ -40,7 +42,12 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     );
 
     let args = warp::any().map(move || redis.clone());
-    let state_route = warp::any().and(args).and_then(state_handler);
+
+    let state_route = warp::any()
+        .and(args)
+        .and_then(state_handler)
+        .recover(handle_rejection);
+
     warp::serve(state_route).run((addr, port)).await;
     Ok(())
 }
@@ -50,17 +57,19 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 async fn state_handler(redis: options::Redis) -> Result<impl warp::Reply, warp::Rejection> {
     let conn = timeout(Duration::from_secs(3), TcpStream::connect(&redis.host))
         .await
-        .map_err(Timeout)?
-        .map_err(IO)?;
+        .map_err(|e| warp::reject::custom(RequestTimeout(e.to_string())))?
+        .map_err(|e| warp::reject::custom(ServiceUnavailable(e.to_string())))?;
 
     let stream = TlsConnector::from(redis.tls.clone())
         .connect(&redis.host, conn)
         .await
-        .map_err(Tls)?;
+        .map_err(|e| warp::reject::custom(ServiceUnavailable(e.to_string())))?;
 
     let mut buf = BufStream::new(stream);
 
-    let result = check_master_status(redis, &mut buf).await.map_err(IO)?;
+    let result = check_master_status(redis, &mut buf)
+        .await
+        .map_err(|e| warp::reject::custom(ServiceUnavailable(e.to_string())))?;
     Ok(result)
 }
 
@@ -83,8 +92,7 @@ async fn check_master_status(
     }
 
     // role:master
-    buf.write_all(b"info replication").await?;
-    buf.write_all(b"\r\n").await?;
+    buf.write_all(b"info replication\r\n").await?;
     buf.flush().await?;
 
     let mut is_master = false;
@@ -102,8 +110,7 @@ async fn check_master_status(
         // uptime
         // to prevent having multiple masters
         // an old-master when starting can start has master before going into replicaof
-        buf.write_all(b"info server").await?;
-        buf.write_all(b"\r\n").await?;
+        buf.write_all(b"info server\r\n").await?;
         buf.flush().await?;
         let mut line = String::new();
         loop {
