@@ -1,13 +1,13 @@
 use anyhow::{Context, Result};
 use clap::{App, Arg};
 use native_tls::{Certificate, Identity, TlsConnector};
-use openssl::pkcs12::Pkcs12;
-use openssl::pkey::{PKey, Private};
-use openssl::x509::X509;
+use openssl::{
+    pkcs12::Pkcs12,
+    pkey::{PKey, Private},
+    x509::X509,
+};
 use rand::{distributions::Alphanumeric, Rng};
-use std::fs;
-use std::io::Read;
-use std::string::ToString;
+use std::{fs, io::Read, string::ToString};
 
 #[derive(Clone, Debug)]
 pub struct Redis {
